@@ -196,7 +196,6 @@ cheese_widget_init (CheeseWidget *widget)
   CheeseWidgetPrivate *priv = widget->priv = CHEESE_WIDGET_GET_PRIVATE (widget);
   GtkWidget           *box;
   ClutterActor        *stage, *frame;
-  ClutterConstraint   *constraint;
   ClutterColor black = { 0x00, 0x00, 0x00, 0xff };
 
   priv->state = CHEESE_WIDGET_STATE_NONE;
@@ -219,17 +218,16 @@ cheese_widget_init (CheeseWidget *widget)
 
   /* Webcam page */
   priv->screen = gtk_clutter_embed_new ();
+  gtk_widget_set_size_request (priv->screen, 460, 345);
   stage = gtk_clutter_embed_get_stage (GTK_CLUTTER_EMBED (priv->screen));
   clutter_actor_set_background_color (stage, &black);
   frame = totem_aspect_frame_new ();
 
   priv->texture = clutter_texture_new ();
-  clutter_actor_set_size (priv->texture, 400, 300);
   totem_aspect_frame_set_child (TOTEM_ASPECT_FRAME (frame), priv->texture);
 
+  clutter_actor_set_layout_manager (stage, clutter_bin_layout_new (CLUTTER_BIN_ALIGNMENT_FILL, CLUTTER_BIN_ALIGNMENT_FILL));
   clutter_actor_add_child (stage, frame);
-  constraint = clutter_bind_constraint_new (stage, CLUTTER_BIND_SIZE, 0.0);
-  clutter_actor_add_constraint_with_name (frame, "size", constraint);
 
   gtk_widget_show (priv->screen);
   clutter_actor_show (priv->texture);
@@ -320,19 +318,15 @@ setup_camera (CheeseWidget *widget)
   g_settings_get (priv->settings, "saturation",   "d", &saturation);
   g_settings_get (priv->settings, "hue",          "d", &hue);
 
-  gdk_threads_enter ();
   priv->webcam = cheese_camera_new (CLUTTER_TEXTURE (priv->texture),
                                     webcam_device,
                                     x_resolution,
                                     y_resolution);
-  gdk_threads_leave ();
 
   g_free (webcam_device);
 
   cheese_camera_setup (priv->webcam, NULL, &priv->error);
 
-  gdk_threads_enter ();
-
   gtk_spinner_stop (GTK_SPINNER (priv->spinner));
 
   if (priv->error != NULL)
@@ -352,8 +346,6 @@ setup_camera (CheeseWidget *widget)
     cheese_camera_play (priv->webcam);
     gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), WEBCAM_PAGE);
   }
-
-  gdk_threads_leave ();
 }
 
 static void
